pub fn split_floor(value: i64, space: OctaveSpace) -> (i64, u16)Expand description
Splits an integer value into a floor octave and folded class for space.
The returned class is always in 0..space.len(), including for negative
inputs.
pub fn split_floor(value: i64, space: OctaveSpace) -> (i64, u16)Splits an integer value into a floor octave and folded class for space.
The returned class is always in 0..space.len(), including for negative
inputs.